@@ -16,7 +16,10 @@ from tests.testing import working_dir
 @pytest.fixture(scope="session", autouse=True)
 def setup_env(request):
     home = working_dir()
-    fs = AzureDLFileSystem(store_name=settings.STORE_NAME, token=settings.TOKEN)
+    fs = AzureDLFileSystem(store_name=settings.STORE_NAME, token_credential=settings.TOKEN_CREDEDENTIAL)
     if settings.RECORD_MODE != 'none':
         if not fs.exists(home):
             fs.mkdir(home)
+        else:
+            fs.rm(home, recursive=True)
+            fs.mkdir(home)
